/**
 * Copyright 2005-2016 The Kuali Foundation
 *
 * Licensed under the Educational Community License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.opensource.org/licenses/ecl2.php
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kuali.rice.core.web.format;

import java.sql.Date;
import java.sql.Timestamp;

/**
 * Formatter that handles Date format (without time) in presentation with a Timestamp in
 * the business object
 */
@Deprecated
public class DateDisplayTimestampObjectFormatter extends DateFormatter {

	private static final long serialVersionUID = 5213490843335374209L;

	@Override
    protected Object convertToObject(String target) {
		return new Timestamp(((Date) super.convertToObject(target)).getTime());
	}

}
